@@ -25,8 +25,7 @@
 #ifndef CLIPLUGIN_H
 #define CLIPLUGIN_H
 
-#include "kerfuffle/cliinterface.h"
-#include "kerfuffle/archiveentry.h"
+#include "cliinterface.h"
 
 class CliPlugin : public Kerfuffle::CliInterface
 {
@@ -34,11 +33,12 @@ class CliPlugin : public Kerfuffle::CliInterface
 
 public:
     explicit CliPlugin(QObject *parent, const QVariantList & args);
-    virtual ~CliPlugin();
+    ~CliPlugin() override;
 
-    virtual void resetParsing() Q_DECL_OVERRIDE;
-    virtual bool readListLine(const QString &line) Q_DECL_OVERRIDE;
-    virtual bool readExtractLine(const QString &line) Q_DECL_OVERRIDE;
+    void resetParsing() override;
+    bool readListLine(const QString &line) override;
+    bool readExtractLine(const QString &line) override;
+    bool readDeleteLine(const QString &line) override;
 
 private:
     enum ArchiveType {
