@@ -154,6 +154,7 @@ bool CliPlugin::readListLine(const QString &line)
         } else {
             m_tempComment.append(line + QLatin1Char('\n'));
         }
+        break;
     case ParseStateEntry:
         QRegularExpressionMatch rxMatch = entryPattern.match(line);
         if (rxMatch.hasMatch()) {
@@ -192,6 +193,7 @@ bool CliPlugin::readExtractLine(const QString &line)
 {
     const QRegularExpression rxUnsupCompMethod(QStringLiteral("unsupported compression method (\\d+)"));
     const QRegularExpression rxUnsupEncMethod(QStringLiteral("need PK compat. v\\d\\.\\d \\(can do v\\d\\.\\d\\)"));
+    const QRegularExpression rxBadCRC(QStringLiteral("bad CRC"));
 
     QRegularExpressionMatch unsupCompMethodMatch = rxUnsupCompMethod.match(line);
     if (unsupCompMethodMatch.hasMatch()) {
@@ -199,11 +201,16 @@ bool CliPlugin::readExtractLine(const QString &line)
         return false;
     }
 
-    if (QRegularExpression(rxUnsupEncMethod).match(line).hasMatch()) {
+    if (rxUnsupEncMethod.match(line).hasMatch()) {
         emit error(i18n("Extraction failed due to unsupported encryption method."));
         return false;
     }
 
+    if (rxBadCRC.match(line).hasMatch()) {
+        emit error(i18n("Extraction failed due to one or more corrupt files. Any extracted files may be damaged."));
+        return false;
+    }
+
     return true;
 }
 
